============
Installation
============

Assuming that OpenStackClient (OSC) is available in your environment, you can easily install Heat-Translator to use with OSC by following three steps::

    git clone https://github.com/openstack/heat-translator
    cd heat-translator
    sudo python setup.py install

You can also clone the project and use it without any specific OpenStack environment set up as below::

    git clone https://github.com/openstack/heat-translator

Heat-Translator can be installed via PyPI package as well. Refer to https://pypi.org/project/heat-translator for available packages.
